==> w1druppel-0.1.7.tgz: package/include/private/ds2482.h <==
#ifndef _DS2482_H
#define _DS2482_H

#include "drup/types.h"

#define CMD_RESET                    0xF0
#define CMD_SET_READ_PTR             0xE1
#define CMD_CHANNEL_SELECT           0xC3

#define CMD_W1_RESET                 0xB4
#define CMD_W1_TRIPLET               0x78
#define CMD_W1_READ_BYTE             0x96
#define CMD_W1_WRITE_BYTE            0xA5
#define CMD_W1_SINGLE_BIT            0x87
#define CMD_WRITE_CONFIG             0xD2

#define STATUS_BUSY                  0x01
#define STATUS_PRESENCE_PULSE_DETECT 0x02
#define STATUS_SINGLE_BIT_READ       0x20
// #define REG_CONFIG_SPEED      0x08

#define SELECT_CODE_STATUS           0xF0
#define SELECT_CODE_DATA             0xE1
#define SELECT_CODE_CONFIG           0xC3
// --- not used
// #define SELECT_CODE_CHANNEL   0xD2
// --- not used

#define W1_MATCH_ROM                 0x55
#define W1_SEARCH_ALARM              0xEC
#define W1_SEARCH_ALL                0xF0
#define W1_SKIP_ROM                  0xCC
#define W1_SKIP_ROM_OVERDRIVE        0x3C

// --- the bit positions of the configuration register.
#define CFG_REG_APU                  0x01
#define CFG_REG_SPU                  0x04
#define CFG_REG_1WS                  0x08

// --- these are just what we call buses, but are called channels in the
// datasheet.

static const uint8_t channels_select[8] = {
  0xF0, 0xE1, 0xD2, 0xC3, 0xB4, 0xA5, 0x96, 0x87,
};

static const uint8_t channels_select_ack[8] = {
  0xB8, 0xB1, 0xAA, 0xA3, 0x9C, 0x95, 0x8E, 0x87,
};

int ds2482_num_buses (int ds2482_type);

bool ds2482_bus_search_init (struct master * master, const struct bus *bus, bool *presence);
bool ds2482_bus_search_start (struct master * master);
bool ds2482_bus_select (struct master *master, const struct bus *bus);

bool ds2482_key_command_init_match_rom (const struct master *master, const struct key *key);
bool ds2482_key_command_init_skip_rom (const struct master *master);
bool ds2482_read_bit (const struct master *master, bool *ret);
bool ds2482_read_byte (const struct master *master, uint8_t *read);
bool ds2482_read_bytes (const struct master *master, uint8_t *read, uint8_t count);
bool ds2482_read_overdrive_on_devices (const struct master * const master, bool *overdrive);
bool ds2482_read_overdrive_on_master (const struct master * const master, bool *overdrive);
bool ds2482_select_register (const struct master *master, uint8_t reg);
bool ds2482_set_overdrive (const struct master *master, bool overdrive);
bool ds2482_triplet (const struct master *master, uint8_t dir, uint8_t *triplet);
bool ds2482_w1_reset (const struct master *master);
bool ds2482_w1_reset_check_presence (const struct master *master, bool *ret);
bool ds2482_wait_idle (const struct master *master, uint8_t *status);
bool ds2482_write_bit (const struct master *master, bool bit);
bool ds2482_write_byte (const struct master *master, uint8_t byte);
bool ds2482_write_bytes (const struct master *master, uint8_t *bytes, uint8_t count);

#endif

==> w1druppel-0.2.3.tgz: package/include/private/ds2482.h <==
#ifndef _DS2482_H
#define _DS2482_H

#include "drup/types.h"

// --- global reset: resets 1WS, SPU, APU.
#define CMD_RESET                    0xF0
#define CMD_SET_READ_PTR             0xE1
#define CMD_CHANNEL_SELECT           0xC3

// --- CMD_W1_RESET, CMD_W1_READ_BYTE, and CMD_W1_WRITE_BYTE use current
// values of 1WS, SPU, APU.
// --- SPU should be off before issuing CMD_W1_RESET.
#define CMD_W1_RESET                 0xB4
#define CMD_W1_TRIPLET               0x78
#define CMD_W1_READ_BYTE             0x96
#define CMD_W1_WRITE_BYTE            0xA5
#define CMD_W1_SINGLE_BIT            0x87
#define CMD_WRITE_CONFIG             0xD2

#define STATUS_BUSY                  0x01
#define STATUS_PRESENCE_PULSE_DETECT 0x02
#define STATUS_SHORT_DETECTED        0x04
#define STATUS_SINGLE_BIT_READ       0x20

#define SELECT_CODE_STATUS           0xF0
#define SELECT_CODE_DATA             0xE1
#define SELECT_CODE_CHANNEL          0xD2
#define SELECT_CODE_CONFIG           0xC3

#define W1_MATCH_ROM                 0x55
#define W1_SEARCH_ALARM              0xEC
#define W1_SEARCH_ALL                0xF0
#define W1_SKIP_ROM                  0xCC
#define W1_SKIP_ROM_OVERDRIVE        0x3C

// --- the bit positions of the configuration register.
#define CFG_REG_APU                  0x01
#define CFG_REG_SPU                  0x04
#define CFG_REG_1WS                  0x08

// --- these are just what we call buses, but are called channels in the
// datasheet.

static const uint8_t channels_select[8] = {
  0xF0, 0xE1, 0xD2, 0xC3, 0xB4, 0xA5, 0x96, 0x87,
};

static const uint8_t channels_select_ack[8] = {
  0xB8, 0xB1, 0xAA, 0xA3, 0x9C, 0x95, 0x8E, 0x87,
};

int ds2482_num_buses (int ds2482_type);

bool ds2482_bus_search_init (struct master * master, const struct bus *bus, uint8_t cfg, bool *presence);
bool ds2482_bus_search_start (struct master * master);
bool ds2482_bus_select (struct master *master, const struct bus *bus);

bool ds2482_key_command_init_match_rom (const struct master *master, const struct key *key);
bool ds2482_key_command_init_skip_rom (const struct master *master);
bool ds2482_read_bit (const struct master *master, bool *ret);
bool ds2482_read_byte (const struct master *master, uint8_t *read);
bool ds2482_read_bytes (const struct master *master, uint8_t *read, uint8_t count);
bool ds2482_read_overdrive_on_devices (const struct master * const master, bool *overdrive);
bool ds2482_read_overdrive_on_master (const struct master * const master, bool *overdrive);
bool ds2482_select_register (const struct master *master, uint8_t reg);
bool ds2482_triplet (const struct master *master, uint8_t dir, uint8_t *triplet);
bool ds2482_w1_reset (const struct master *master);
bool ds2482_w1_reset_check_presence (const struct master *master, bool *ret);
bool ds2482_wait_idle (const struct master *master, uint8_t *status);
bool ds2482_write_bit (const struct master *master, bool bit);
bool ds2482_write_byte (const struct master *master, uint8_t byte);
bool ds2482_write_bytes (const struct master *master, uint8_t *bytes, uint8_t count);
bool ds2482_write_configuration (const struct master *master, uint8_t cfg);

#endif
